==> haskell-streaming-commons-0.1.15.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-streaming-commons/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.1.15.2
id: streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
key: strea_0Pv1kz8leJoAmtjyRTUWHG
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
author: Michael Snoyman, Emanuel Borsboom
exposed: True
exposed-modules:
    Data.Streaming.Blaze Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer
    Data.Streaming.ByteString.Builder.Class Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/streaming-commons-0.1.15.2
hs-libraries: HSstreaming-commons-0.1.15.2-0Pv1kz8leJoAmtjyRTUWHG
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.1.15-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-streaming-commons/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.1.15
id: streaming-commons-0.1.15-43ddfb983feecf5e5c9c7ab99b5e44ed
key: strea_3e8TuBnfkBU5pVfOKBg2n7
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
author: Michael Snoyman, Emanuel Borsboom
exposed: True
exposed-modules:
    Data.Streaming.Blaze Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer
    Data.Streaming.ByteString.Builder.Class Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15
library-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15
data-dir: /usr/share/arm-linux-ghc-7.10.3/streaming-commons-0.1.15
hs-libraries: HSstreaming-commons-0.1.15-3e8TuBnfkBU5pVfOKBg2n7
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
